/**
 * Is the DOM ready?
 *
 * This implementation is coming from https://gomakethings.com/a-native-javascript-equivalent-of-jquerys-ready-method/
 *
 * @since Iceberg 2.1
 *
 * @param {Function} fn Callback function to run.
 */
function icebergDomReady( fn ) {
	if ( typeof fn !== 'function' ) {
		return;
	}

	if ( document.readyState === 'interactive' || document.readyState === 'complete' ) {
		return fn();
	}

	document.addEventListener( 'DOMContentLoaded', fn, false );
}

icebergDomReady( function() {
	var body = document.body;

	/* Preloader */
	if( icebergVars.preloaderEnabled && typeof imagesLoaded === "function" ) {
		imagesLoaded( body, function( instance ) {
			body.classList.add( 'site-loaded' );
		});
	}

	/* Init Swiper */
	if ( typeof Swiper === 'function' ) {
		const swiper = new Swiper('.iceberg-swiper', {
			loop: true,
			autoHeight: true,
			speed: parseInt( icebergSwiperVars.speed ),
			autoplay: {
				delay: parseInt( icebergSwiperVars.autoplayDelay )
			},
			pagination: { ...(!!icebergSwiperVars.pagination) && { el: '.swiper-pagination', type: 'bullets', clickable: true } },
			navigation: {
				nextEl: '.swiper-button-next',
				prevEl: '.swiper-button-prev',
			},
			a11y: {
				firstSlideMessage: icebergSwiperVars.firstSlideMessage,
				lastSlideMessage: icebergSwiperVars.lastSlideMessage,
				paginationBulletMessage: icebergSwiperVars.paginationBulletMessage,
			    prevSlideMessage: icebergSwiperVars.prevSlideMessage,
			    nextSlideMessage: icebergSwiperVars.nextSlideMessage,
			    containerMessage: icebergSwiperVars.containerMessage,
			    containerRoleDescriptionMessage: icebergSwiperVars.containerRoleDescriptionMessage,
			    itemRoleDescriptionMessage: icebergSwiperVars.itemRoleDescriptionMessage
			}
		});
	}
} );

